@@ -1,4 +1,4 @@
-check_radius(r) = r < 0 && throw(ArgumentError("the query radius r must be ≧ 0"))
+check_radius(r) = r < zero(r) && throw(ArgumentError("the query radius r must be ≧ 0"))
 
 """
     inrange(tree::NNTree, points, radius) -> indices
@@ -142,3 +142,8 @@ function inrangecount_matrix(tree::NNTree{V}, points::AbstractMatrix{T}, radius:
     end
     return counts
 end
+
+function inrange_pairs(tree::NNTree, radius::Number, sortres=false, skip::F=Returns(false)) where {F}
+    check_radius(radius)
+    return _inrange_pairs(tree, radius, sortres, skip)
+end
